# Current goals

- Add an in-line CLI mode for the demo.
- Get original Pyfiglet test suite fully working.
- Add my own unit tests.
- Add A Pyfiglet button.
- Add options for kerning and other settings. Modify Pyfiglet internals if necessary.
- Add ability to strip all blank lines.
- Add ability to set gradient in sideways / left-right mode.
- Add corresponding left-right animation.
- Add in Textual's splash gradient ability as see in Textual's examples/splash.py.
